@@ -68,9 +68,19 @@ User = {
     }
 }
 
+BriefQuery = {
+    'include': [':pk', 'name', 'context_json', 'view_json'],
+    'allow_missing': True,
+}
+
+ForkedQuery = {
+    'fields': [':pk', 'parent'],
+    'allow_missing': True,
+}
+
 Query = {
     'fields': [':pk', 'accessed', 'name', 'description', 'user',
-               'shared_users', 'context_json', 'view_json'],
+               'shared_users', 'context_json', 'view_json', 'public'],
     'related': {
         'user': User,
         'shared_users': User,
